@@ -1,12 +1,12 @@
 from primestg.report.base import (
     MeasureActiveReactive, MeasureActiveReactiveFloat, Parameter,
     MeterWithMagnitude, ConcentratorWithMetersWithConcentratorName,
-    Concentrator, Measure, MeterWithConcentratorName
+    Concentrator, Measure, MeterWithConcentratorName, LineDetails, RemoteTerminalUnitDetails
 )
 from primestg.message import MessageS
 
 SUPPORTED_REPORTS = ['S02', 'S04', 'S05', 'S06', 'S09', 'S12', 'S13', 'S15',
-                     'S17', 'S23', 'S24', 'S27']
+                     'S17', 'S18', 'S23', 'S24', 'S27', 'S52']
 
 
 def is_supported(report_code):
@@ -260,6 +260,33 @@ class MeasureS27(MeasureActiveReactive):
         return values
 
 
+class MeasureS52(MeasureActiveReactiveFloat):
+    """
+    Class for a set of measures of report S52.
+    """
+
+    @property
+    def values(self):
+        """
+        Set of measures of report S52.
+
+        :return: a dict with a set of measures of report S52
+        """
+        try:
+            values = self.active_reactive(self.objectified, '')
+            values.update(
+                {
+                    'timestamp': self._get_timestamp('Fh'),
+                    'bc': self.objectified.get('Bc')
+                }
+            )
+        except Exception as e:
+            self._warnings.append('ERROR: Thrown exception: {}'.format(e))
+            return []
+
+        return [values]
+
+
 class MeasureEvents(Measure):
     """
     Class for a set of measures of report S09.
@@ -894,6 +921,42 @@ class ParameterConcentratorEvents(Parameter):
         return values
 
 
+class LineS52(LineDetails):
+    """
+    Class for a line of report S52.
+    """
+
+    @property
+    def report_type(self):
+        """
+        The type of report for report S52.
+
+        :return: a string with 'S52'
+        """
+        return 'S52'
+
+    @property
+    def measure_class(self):
+        """
+        The class used to instance measure sets for report S52.
+
+        :return: a class to instance measure sets of report S52
+        """
+        return MeasureS52
+
+    @property
+    def values(self):
+        """
+        Values of measure sets of this line of report that need the name of the remote terminal unit and the line
+
+        :return: a list with the values of the measure sets
+        """
+        values = super(LineS52, self).values
+        for value in values:
+            value['magn'] = self.magnitude
+        return values
+
+
 class MeterS01(MeterWithMagnitude):
     """
     Class for a meter of report S01.
@@ -1712,6 +1775,69 @@ class ConcentratorS17(ConcentratorEvents):
         return parameters
 
 
+class MeasureS18(MeasureActiveReactive):
+    """
+    Class for a set of measures of report S18.
+    """
+    @property
+    def values(self):
+        """
+        Set of measures of report S18.
+        :return: a dict with a set of measures of report S18.
+        """
+        values = {}
+        try:
+            get = self.objectified.get
+            values.update({
+                'order_datetime': self._get_timestamp('Fh'),
+                'orden': get_integer_value(get('Orden')),
+            })
+
+        except Exception as e:
+            self._warnings.append('ERROR: Thrown exception: {}'.format(e))
+            return []
+        return [values]
+
+
+class MeterS18(MeterWithMagnitude):
+    """
+    Class for a meter of report S18.
+    """
+
+    @property
+    def report_type(self):
+        """
+        The type of report for report S18.
+
+        :return: a string with 'S18'
+        """
+        return 'S18'
+
+    @property
+    def measure_class(self):
+        """
+        The class used to instance measure sets for report S18.
+
+        :return: a class to instance measure sets of report S18
+        """
+        return MeasureS18
+
+
+class ConcentratorS18(ConcentratorWithMetersWithConcentratorName):
+    """
+    Class for a set of measures of report S18.
+    """
+
+    @property
+    def meter_class(self):
+        """
+        The class used to instance meters for report S18.
+
+        :return: a class to instance meters of report S18
+        """
+        return MeterS18
+
+
 class ConcentratorS21(ConcentratorWithMetersWithConcentratorName):
     """
     Class for a concentrator of report S01.
@@ -1801,6 +1927,21 @@ class ConcentratorS24(Concentrator):
         return values
 
 
+class RemoteTerminalUnitS52(RemoteTerminalUnitDetails):
+    """
+    Class for a remote terminal unit of report S52.
+    """
+
+    @property
+    def line_class(self):
+        """
+        The class used to instance lines for report S52.
+
+        :return: a class to instance lines of report S52
+        """
+        return LineS52
+
+
 class Report(object):
     """
     Report class to process MessageS
@@ -1931,6 +2072,10 @@ class Report(object):
                     self.report_type
                 ]
             },
+            'S18': {
+                'class': ConcentratorS18,
+                'args': [objectified_concentrator]
+            },
             'S21': {
                 'class': ConcentratorS21,
                 'args': [objectified_concentrator]
@@ -1951,7 +2096,7 @@ class Report(object):
             'S27': {
                 'class': ConcentratorS27,
                 'args': [objectified_concentrator]
-            },
+            }
         }
 
         if self.report_type not in report_type_class:
@@ -1963,6 +2108,28 @@ class Report(object):
         concentrator = concentrator_class(*concentrator_args)
         return concentrator
 
+    def get_rt_unit(self, objectified_rt_unit):
+        """
+        Instances a remote terminal unit object
+
+        :return: a remote terminal unit object
+        """
+        report_type_class = {
+            'S52': {
+                'class': RemoteTerminalUnitS52,
+                'args': [objectified_rt_unit]
+            }
+        }
+
+        if self.report_type not in report_type_class:
+            raise NotImplementedError('Report type not implemented!')
+
+        get = report_type_class.get(self.report_type).get
+        rt_unit_class = get('class')
+        rt_unit_args = get('args')
+        rt_unit = rt_unit_class(*rt_unit_args)
+        return rt_unit
+
     @property
     def supported(self):
         return is_supported(self.report_type)
@@ -1976,6 +2143,15 @@ class Report(object):
         """
         return map(self.get_concentrator, self.message.objectified.Cnc)
 
+    @property
+    def rt_units(self):
+        """
+        The remote terminal units of the report.
+
+        :return: a list of remote terminals units of the report
+        """
+        return map(self.get_rt_unit, self.message.objectified.Rtu)
+
     @property
     def values(self):
         """
@@ -1984,6 +2160,10 @@ class Report(object):
         :return: a list with the values of the whole report
         """
         values = []
-        for concentrator in self.concentrators:
-            values.extend(concentrator.values)
+        if self.report_type == 'S52':
+            for rt_unit in self.rt_units:
+                values.extend(rt_unit.values)
+        else:
+            for concentrator in self.concentrators:
+                values.extend(concentrator.values)
         return values
